@@ -52,8 +52,9 @@ def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibCl
     nft_items = []
 
     for i in range(ceil(len(addresses) / max_requests)):
-        if not client or not client.tonlib_wrapper._is_working:
-            client = get_client(ls)
+        if client and client.tonlib_wrapper._is_working:
+            asyncio.get_event_loop().run_until_complete(client.tonlib_wrapper.close())
+        client = get_client(ls)
         tasks = []
         for addr in addresses[i * max_requests:min(len(addresses), max_requests * (i + 1))]:
             tasks.append(get_item(client, addr, nft_items, items))
